@@ -10,6 +10,7 @@ use structopt::StructOpt;
 pub mod cli;
 pub mod config;
 pub mod constants;
+pub mod diff;
 pub mod error;
 pub mod file_handler;
 pub mod generator;
@@ -72,6 +73,7 @@ fn main() -> Result<(), ExitFailure> {
             run_wa,
             run_tle,
             run_rte,
+            diff,
         } => subcommand::cmd_cmp::run(
             target_file,
             correct_file,
@@ -86,6 +88,7 @@ fn main() -> Result<(), ExitFailure> {
             run_wa,
             run_tle,
             run_rte,
+            diff,
         ),
         Opt::Check {
             target_file,
